@@ -25,6 +25,7 @@
       $squirrelmail_plugin_hooks["left_main_before"]["addgraphics"] = "addgraph_left";
    }
 
+
    function addgraph_left() {
 
       if (defined('SM_PATH'))
@@ -36,4 +37,10 @@
 
    }
 
+
+   function addgraphics_version()
+   {
+      return '2.1';
+   }
+
 ?>
